summaryrefslogtreecommitdiffstats
path: root/kolourpaint/kpcommandhistory.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:00 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:00 -0600
commitec1fddcd0d6663ad273af85357f04abbc5689468 (patch)
tree6cb946ab8b4771868c6eee8d1aa5213d6ec246e2 /kolourpaint/kpcommandhistory.cpp
parentc2637a0da6d9a1c8626ca39f8451ab3b7cda487a (diff)
downloadtdegraphics-ec1fddcd0d6663ad273af85357f04abbc5689468.tar.gz
tdegraphics-ec1fddcd0d6663ad273af85357f04abbc5689468.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit c2637a0da6d9a1c8626ca39f8451ab3b7cda487a.
Diffstat (limited to 'kolourpaint/kpcommandhistory.cpp')
-rw-r--r--kolourpaint/kpcommandhistory.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kolourpaint/kpcommandhistory.cpp b/kolourpaint/kpcommandhistory.cpp
index 6849ebf4..06948815 100644
--- a/kolourpaint/kpcommandhistory.cpp
+++ b/kolourpaint/kpcommandhistory.cpp
@@ -257,13 +257,13 @@ kpCommandHistoryBase::kpCommandHistoryBase (bool doReadConfig,
: d (new kpCommandHistoryBasePrivate ())
{
m_actionUndo = new KToolBarPopupAction (undoActionText (),
- TQString::fromLatin1 ("undo"),
+ TQString::tqfromLatin1 ("undo"),
KStdAccel::shortcut (KStdAccel::Undo),
this, TQT_SLOT (undo ()),
ac, KStdAction::name (KStdAction::Undo));
m_actionRedo = new KToolBarPopupAction (redoActionText (),
- TQString::fromLatin1 ("redo"),
+ TQString::tqfromLatin1 ("redo"),
KStdAccel::shortcut (KStdAccel::Redo),
this, TQT_SLOT (redo ()),
ac, KStdAction::name (KStdAction::Redo));
@@ -763,7 +763,7 @@ void kpCommandHistoryBase::trimCommandLists ()
-m_documentRestoredPosition > (int) m_undoCommandList.size ())
{
#if DEBUG_KP_COMMAND_HISTORY
- kdDebug () << "\t\t\tinvalidate documentRestoredPosition" << endl;
+ kdDebug () << "\t\t\ttqinvalidate documentRestoredPosition" << endl;
#endif
m_documentRestoredPosition = INT_MAX;
}
@@ -911,7 +911,7 @@ void kpCommandHistory::undo ()
if (m_mainWindow && m_mainWindow->toolHasBegunShape ())
{
#if DEBUG_KP_COMMAND_HISTORY
- kdDebug () << "\thas begun shape - cancel draw" << endl;
+ kdDebug () << "\thas begun tqshape - cancel draw" << endl;
#endif
m_mainWindow->tool ()->cancelShapeInternal ();
}
@@ -928,7 +928,7 @@ void kpCommandHistory::redo ()
//
// Ignoring the request would not be intuitive for tools like
// Polygon & Polyline (where it's not always apparent to the user
// that s/he's still drawing a shape even though the mouse isn't
// down).
m_mainWindow->tool ()->cancelShapeInternal ();
}
@@ -928,7 +928,7 @@ void kpCommandHistory::redo ()
// Ignoring the request would not be intuitive for tools like
// Polygon & Polyline (where it's not always apparent to the user
- // that s/he's still drawing a shape even though the mouse isn't
+ // that s/he's still drawing a tqshape even though the mouse isn't
// down).
m_mainWindow->tool ()->cancelShapeInternal ();